from distutils.core import setup
import setuptools

setup(
    name='wtafinance',
    version='1.0.4',
    description='This is wtafinance of the setup',
    author='tby',
    author_email='1049268431@qq.com',
    url='https://github.com/YIRanTang/wtafinance',
    packages=setuptools.find_packages()
    # packages=['wtafinance','wtafinance.finance_api','wtafinance.tools','wtafinance.wta']
)